@@ -253,9 +253,9 @@ class EventbridgeToKinesisStreamsProps:
         :summary: The properties for the EventbridgeToKinesisStreams Construct
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = RuleProps(**event_rule_props)
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = EventBusProps(**event_bus_props)
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if __debug__:
             type_hints = typing.get_type_hints(EventbridgeToKinesisStreamsProps.__init__)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
